@@ -29,7 +29,7 @@ SearchToolBar::SearchToolBar(WebView* view, QWidget* parent)
     : QWidget(parent)
     , ui(new Ui::SearchToolbar)
     , m_view(view)
-    , m_findFlags(0)
+    , m_findFlags{}
 {
     setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(this);
@@ -38,6 +38,11 @@ SearchToolBar::SearchToolBar(WebView* view, QWidget* parent)
     ui->next->setShortcut(QKeySequence("Ctrl+G"));
     ui->previous->setShortcut(QKeySequence("Ctrl+Shift+G"));
 
+    ui->resultsInfo->hide();
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    connect(view->page(), &QWebEnginePage::findTextFinished, this, &SearchToolBar::showSearchResults);
+#endif
+
     connect(ui->closeButton, SIGNAL(clicked()), this, SLOT(close()));
     connect(ui->lineEdit, &QLineEdit::textEdited, this, &SearchToolBar::findNext);
     connect(ui->next, &QAbstractButton::clicked, this, &SearchToolBar::findNext);
@@ -57,7 +62,6 @@ void SearchToolBar::showMinimalInPopupWindow()
 {
     // Show only essentials widget + set minimum width
     ui->caseSensitive->hide();
-    ui->results->hide();
     ui->horizontalLayout->setSpacing(2);
     ui->horizontalLayout->setContentsMargins(2, 6, 2, 6);
     setMinimumWidth(260);
@@ -78,7 +82,7 @@ void SearchToolBar::close()
 
 void SearchToolBar::findNext()
 {
-    m_findFlags = 0;
+    m_findFlags = {};
     updateFindFlags();
 
     searchText(ui->lineEdit->text());
@@ -129,11 +133,6 @@ void SearchToolBar::searchText(const QString &text)
         if (ui->lineEdit->text().isEmpty())
             found = true;
 
-        if (!found)
-            ui->results->setText(tr("No results found."));
-        else
-            ui->results->clear();
-
         ui->lineEdit->setProperty("notfound", QVariant(!found));
         ui->lineEdit->style()->unpolish(ui->lineEdit);
         ui->lineEdit->style()->polish(ui->lineEdit);
@@ -143,6 +142,20 @@ void SearchToolBar::searchText(const QString &text)
     });
 }
 
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+void SearchToolBar::showSearchResults(const QWebEngineFindTextResult &result)
+{
+    if (result.numberOfMatches() == 0) {
+        ui->resultsInfo->hide();
+        return;
+    }
+
+    ui->resultsInfo->setText(tr("%1 of %2").arg(
+        QString::number(result.activeMatch()), QString::number(result.numberOfMatches())));
+    ui->resultsInfo->show();
+}
+#endif
+
 bool SearchToolBar::eventFilter(QObject* obj, QEvent* event)
 {
     Q_UNUSED(obj);
